ChangeLog
=========

0.0.2 (2016/08/08)
------------------

- add support for validating object attributes and dictionary items
- add schema generation from a dictionary or object.

0.0.1 (2016/06/06)
------------------

- library creation.
